@@ -266,13 +266,17 @@ class muapi_client:
                 print(sys.exc_info())
             raise MyError('Error')
 
-    def get_item_list(self, resource, item_name=None, item_url=None, region=None, page=None, per_page=100):
+    def get_item_list(self, resource, item_name=None, item_url=None, region=None, page=None, per_page=100,
+                      date_start=None, date_finish=None):
         data = {
             'resource': resource,
             'item': {}
         }
         if item_name is not None:
             data['item']['name'] = item_name
+        if date_start is not None and date_finish is not None:
+            data['item']['updated_at'] = {'$gte': date_start,
+                                          '$lt': date_finish}
         if item_url is not None:
             item_url = self.encode_url(item_url)
             data['item']['url'] = item_url
